summaryrefslogtreecommitdiff
path: root/data
diff options
context:
space:
mode:
authorAlexander Beisig <alexander.beisig@gmx.de>2006-08-03 19:28:31 +0000
committerAlexander Beisig <alexander.beisig@gmx.de>2006-08-03 19:28:31 +0000
commit6c470685174bdee375beb2d968059172d5689575 (patch)
tree261d65d4cfe5b7f375ad4f8a8b8494f681c23595 /data
parent9e008a694be3c87e7cf13f9b5c353d32afd4468a (diff)
renamed keywords plugin to fix inconsistency between commands and help
Diffstat (limited to 'data')
-rw-r--r--data/rbot/plugins/keywords.rb10
1 files changed, 5 insertions, 5 deletions
diff --git a/data/rbot/plugins/keywords.rb b/data/rbot/plugins/keywords.rb
index e743f2b9..3ae76024 100644
--- a/data/rbot/plugins/keywords.rb
+++ b/data/rbot/plugins/keywords.rb
@@ -71,14 +71,14 @@ class Keyword
end
end
-# keywords class.
+# keyword plugin class.
#
# Handles all that stuff like "bot: foo is bar", "bot: foo?"
#
# Fallback after core and auth have had a look at a message and refused to
# handle it, checks for a keyword command or lookup, otherwise the message
# is delegated to plugins
-class Keywords < Plugin
+class KeywordPlugin < Plugin
BotConfig.register BotConfigBooleanValue.new('keyword.listen',
:default => false,
:desc => "Should the bot listen to all chat and attempt to automatically detect keywords? (e.g. by spotting someone say 'foo is bar')")
@@ -86,7 +86,7 @@ class Keywords < Plugin
:default => true,
:desc => "Should the bot require that keyword lookups are addressed to it? If not, the bot will attempt to lookup foo if someone says 'foo?' in channel")
# create a new Keywords instance, associated to bot +bot+
def initialize
super
@@ -330,7 +330,7 @@ class Keywords < Plugin
when "<topic>"
return "<topic> => respond by setting the topic to the rest of the definition"
when "search"
- return "keywords search [--all] [--full] <regexp> => search keywords for <regexp>. If --all is set, search static keywords too, if --full is set, search definitions too."
+ return "keyword search [--all] [--full] <regexp> => search keywords for <regexp>. If --all is set, search static keywords too, if --full is set, search definitions too."
else
return "Keyword module (Fact learning and regurgitation) topics: overview, set, plurals, override, also, random, get, tell, forget, keywords, keywords search, <reply>, <action>, <who>, <topic>"
end
@@ -455,7 +455,7 @@ class Keywords < Plugin
end
end
-plugin = Keywords.new
+plugin = KeywordPlugin.new
plugin.map 'keyword stats', :action => 'keyword_stats'
@@ -86,7 +86,7 @@ class Keywords < Plugin
:default => true,
:desc => "Should the bot require that keyword lookups are addressed to it? If not, the bot will attempt to lookup foo if someone says 'foo?' in channel")
- # create a new Keywords instance, associated to bot +bot+
+ # create a new KeywordPlugin instance, associated to bot +bot+
def initialize
super